#!/bin/sh

if [ -z "$PREFIX" ]; then
	echo "ERROR: set \$PREFIX before sourcing this script!"
	exit 1
fi

SW_VERSION=`sw_vers -productVersion | cut -d. -f1-2`
case $SW_VERSION in
	10.[01])
		echo "unsupported OS version: $SW_VERSION"
		exit 1
		;;
	10.2)
		export MACOSX_DEPLOYMENT_TARGET=10.2
		FREETYPE_CONFIG=$PREFIX/bin/freetype-config
		;;
	*)
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
esac

LDFLAGS=""

#for dir in freetype2 xft2 render1 fontconfig2 xrender1 flex; do
for dir in freetype219 flex; do
	if [ -d "$PREFIX/lib/$dir" ]; then
		for incdir in "$PREFIX/lib/$dir/include/freetype2" "$PREFIX/lib/$dir/include"; do
			if [ -d "$incdir" ]; then
				export CPPFLAGS="$CPPFLAGS -I$incdir"
			fi
		done
		export LDFLAGS="-L$PREFIX/lib/$dir/lib $LDFLAGS"
		export PATH="$PREFIX/lib/$dir/bin:$PATH"
		export PKG_CONFIG_PATH="$PREFIX/lib/$dir/lib/pkgconfig"
	fi
done

# -fast, minus the unsafe bits
if [ -d "libltdl" ]; then
	export ACLOCALFLAGS="$ACLOCALFLAGS -I libltdl"
fi
export CFLAGS="-Os -fPIC"
export CXXFLAGS="$CFLAGS"
export CPPFLAGS="$CPPFLAGS -fno-common -no-cpp-precomp -DMACOSX -DARTS_NO_ALARM -I$PREFIX/include -I/usr/X11R6/include"
export FREETYPE_CONFIG
export LIBS="$LIBS -L$PREFIX/lib -L/usr/X11R6/lib"
export SED="sed"

PATH=`echo $PATH | perl -p -e 'for my $entry (split(/:/, $_)) { next if ($entry =~ m,^/usr/local,); push(@path, $entry) }; $_ = join(":", @path)'`
export PATH="$PATH:/usr/X11R6/bin"

export ALL_LIBRARIES="$LDFLAGS -L$PREFIX/lib -L/usr/X11R6/lib"

cat <<END
the following environment is being used:

  ACLOCALFLAGS:             $ACLOCALFLAGS
  CFLAGS:                   $CFLAGS
  CPPFLAGS:                 $CPPFLAGS
  CXXFLAGS:                 $CXXFLAGS
  FREETYPE_CONFIG:          $FREETYPE_CONFIG
  LDFLAGS:                  $LDFLAGS
  LIBS:                     $LIBS
  MACOSX_DEPLOYMENT_TARGET: $MACOSX_DEPLOYMENT_TARGET
  PATH:                     $PATH
  PKG_CONFIG_PATH:          $PKG_CONFIG_PATH

END

